@@ -1,13 +1,20 @@
 from importlib import metadata
 
-from smallgraphlib.graph import Graph, DirectedGraph
-from smallgraphlib.labeled_graph import (
+from smallgraphlib.basic_graphs import Graph, DirectedGraph
+from smallgraphlib.labeled_graphs import (
     WeightedGraph,
     WeightedDirectedGraph,
     LabeledGraph,
     LabeledDirectedGraph,
 )
-from smallgraphlib.graphs_constructors import complete_graph, complete_bipartite_graph, graph, random_graph
+from smallgraphlib.graphs_constructors import (
+    complete_graph,
+    complete_bipartite_graph,
+    graph,
+    random_graph,
+    perfect_binary_tree,
+)
+from smallgraphlib.core import Traversal
 
 __version__ = metadata.version(__package__)
 
@@ -23,4 +30,6 @@ __all__ = [
     "complete_graph",
     "graph",
     "complete_bipartite_graph",
+    "perfect_binary_tree",
+    "Traversal",
 ]
